<?php
/*
 * @Descripttion: 
 * @version: 1.0.0
 * @Author: likang
 * @Date: 2022-08-12 11:31:01
 * @LastEditors: likang
 * @LastEditTime: 2022-08-13 17:00:52
 */

namespace catchAdmin\tag_history\controller;

use catchAdmin\report\model\Report;
use catcher\base\CatchRequest as Request;
use catcher\CatchResponse;
use catcher\base\CatchController;
use catchAdmin\tag_history\model\TagHistory as tagHistoryModel;
use catcher\CatchAdmin;
use think\facade\Db;

class TagHistory extends CatchController
{
    protected $tagHistoryModel;

    public function __construct(TagHistoryModel $tagHistoryModel)
    {
        $this->tagHistoryModel = $tagHistoryModel;
    }

    /**
     * 列表
     * @time 2022年08月12日 11:31
     * @param Request $request 
     */
    public function index(Request $request): \think\Response
    {
        $data = $request->get();
        $time =  isset($data['time']) ? $data['time'] : '';
        $mac = isset($data['mac']) ? $data['mac'] : '';
        $tage = isset($data['tage']) ? $data['tage'] : '';
        $endtime = isset($data['endtime']) ? $data['endtime'] : "";
        $meter = isset($data['meter']) ? $data['meter'] : "";
        $where = [];
        if (!empty($time)) {
            $where[] = ['addTime', '>=', $time];
        } else {
            $where[] = ['addTime', '>=', time()];
        }

        if (!empty($mac)) {

            $where[] = ['mac', 'in',  implode(",", $mac)];
        }
        if (!empty($tage)) {
            $where[] = ['lable', 'in',  implode(",", $tage)];
        }
        if ($endtime == 1) {
            //生成报告
            $end = time();

            $tagList =  $this->tagHistoryModel->where($where)->where('addTime', '<=', $end)->select();
            $content = [
                'mac' => json_encode($mac),
                'lable' => json_encode($tage),
                'meter' => $meter,
                'startTime' => $time,
                'endTime' => $end,
                'data' => json_encode($tagList)
            ];
            $report = new Report();
            $report->save($content);
        }

        $list = $this->tagHistoryModel->group('mac,lable')->where($where)
            ->field('mac,lable,max(addTime) as addTime,AVG(rssi) as ave_rssi,count(*) as num')->select()->toArray();

        foreach ($list as $key => $value) {
            $wheres = [];
            $da = null;
            $wheres[] = ['mac', '=', $value['mac']];
            $wheres[] = ['lable', '=', $value['lable']];
            $wheres[] = ['addTime', '=', $value['addTime']];
            $da = $this->tagHistoryModel->where($wheres)->find();
            $list[$key]['rssi'] = $da['rssi'];
            $list[$key]['addTime'] = date('Y-m-d H:i:s', $value['addTime']);
            $list[$key]['time'] = date('Y-m-d H:i:s', $da['time']);
            $list[$key]['id'] = $da['id'];
        }
        return CatchResponse::success($list);
    }

    /**
     * 保存信息
     * @time 2022年08月12日 11:31
     * @param Request $request 
     */
    public function save(Request $request): \think\Response
    {
        return CatchResponse::success($this->tagHistoryModel->storeBy($request->post()));
    }

    /**
     * 读取
     * @time 2022年08月12日 11:31
     * @param $id 
     */
    public function read($id): \think\Response
    {
        return CatchResponse::success($this->tagHistoryModel->findBy($id));
    }

    /**
     * 更新
     * @time 2022年08月12日 11:31
     * @param Request $request 
     * @param $id
     */
    public function update(Request $request, $id): \think\Response
    {
        return CatchResponse::success($this->tagHistoryModel->updateBy($id, $request->post()));
    }

    /**
     * 删除
     * @time 2022年08月12日 11:31
     * @param $id
     */
    public function delete($id): \think\Response
    {
        return CatchResponse::success($this->tagHistoryModel->deleteBy($id));
    }

    /**
     * @Descripttion: 获取设备
     * @name: likang
     * @return {*}
     */
    public function getStations()
    {

        $list = $this->tagHistoryModel->group('mac')->column('mac');
        return CatchResponse::success($list);
    }
    /**
     * @Descripttion: 获取标签
     * @name: likang
     * @return {*}
     */
    public function getTages()
    {
        $list = $this->tagHistoryModel->group('lable')->column('lable');
        return CatchResponse::success($list);
    }
    /**
     * @Descripttion: 获取时间
     * @name: likang
     * @return {*}
     */
    public function getTime()
    {

        $time = time();
        return CatchResponse::success($time);
    }
}
